#!/bin/sh

# Datei: tarBackup.sh
#
#***********************************************************************************************
# Dateisicherung mit dem tar-Befehl
#
# Aufruf: ./tarBackup.sh [gesamt]
#
# Sichert Dateien und Verzeichnisse, die in diesem Skript in "BACKUP_LIST" angegeben sind. Wird
# als Parameter "gesamt" bergeben, so wird eine vollstndige Sicherung gemacht, sonst nur eine
# inkrementelle Sicherung. Bei jeder gesamtsicherung werden die inkrementellen Sicherungen
# gelscht.
#***********************************************************************************************


START_DIR="$HOME/LUG/tar/TEST"
# Verzeichnisse und Dateien relativ zu "START_DIR", die gesichert werden sollen
BACKUP_LIST="./t1 ./t2"
# Mail Adresse, an die eine Nachricht geschickt wird, wenn ein Fehler aufgetreten ist
MAIL_ADDR=alexander

# Verzeichnis in dem sich dieses Skript und Hilfsdateien befinden
TAR_DIR="$HOME/LUG/tar"
# Name der Logdatei
LOG_FILE=$TAR_DIR/backup.log
# Name der Datei, in der Informationen ber die inkrementelle Sicherung gespeichert werden
INCR_FILE=$TAR_DIR/backup.inc
# Name der Datei, die einen Zhler fr die inkrementellen Sicherungn enthlt
COUNT_FILE=$TAR_DIR/backup.cnt


if [ "$1" == "gesamt" ]; then
# Parameter fr die GESAMTSICHERUNG
	# Name der Tar-Datei
	TAR_FILE=$HOME/LUG/tar/backup_`date "+%Y-%m-%d"`.tgz
	BUP_TYP=Gesamtsicherung
	# Zhler initialisieren
	echo 0 > $COUNT_FILE
	# alte inkrementelle Sicherungen und Inkrement-Infos lschen
	/bin/rm -f $HOME/LUG/tar/Ibackup_*.tgz $INCR_FILE
else
# Parameter fr die INKREMENTELLE SICHERUNG
	BUP_TYP="Inkrementelle Sicherung"
	if [ -w $COUNT_FILE ]; then
		iCount=`cat $COUNT_FILE`
		# Zhler um 1 erhhen
		iCount=$((iCount + 1))
	else
		iCount=1
	fi
	# Name der Tar-Datei
	TAR_FILE=$HOME/LUG/tar/Ibackup_$iCount.tgz
	# Zhler speichern
	echo $iCount > $COUNT_FILE
fi

# Start-Meldung mit Datum und Uhrzeit ausgeben
date "+ --->$BUP_TYP gestartet am %d.%m.%Y %H:%M" | tee -a $LOG_FILE

# Hier das eigentliche Sicherungskommando
tar zcfg $TAR_FILE $INCR_FILE --exclude='*~' --directory=$START_DIR $BACKUP_LIST 2>> $LOG_FILE >> $LOG_FILE
if [ "$?" != "0" ]; then
# der letzte Befehl (tar) ist fehlerhaft beendet worden
	# Mail mit fehlernachricht verschicken
	(date "+$BUP_TYP: Am %d.%m.%Y %H:%M:%S trat ein Fehler auf, siehe Logdatei '$LOG_FILE'."  | \
	 mail -s "Backup Fehler" $MAIL_ADDR) &
	# Fehlernachricht ausgeben
	echo "**** Sicherung Fehlgeschlagen" | tee -a $LOG_FILE
	exit 1
fi

# Ende-Meldung mit Datum und Uhrzeit ausgeben
date "+ <---$BUP_TYP beendet am %d.%m.%Y %H:%M" | tee -a $LOG_FILE
